@@ -5,9 +5,12 @@
  * This file brings in all of the dependencies that every Mnemo
  * script will need and sets up objects that all scripts use.
  *
- * $Horde: mnemo/lib/base.php,v 1.46.10.12 2008/01/02 16:50:49 chuck Exp $
+ * The following global variables are used:
+ *   $no_compress  -  Controls whether the page should be compressed
  *
- * Copyright 2001-2008 The Horde Project (http://www.horde.org/)
+ * $Horde: mnemo/lib/base.php,v 1.46.10.14 2009/08/12 22:28:13 jan Exp $
+ *
+ * Copyright 2001-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -54,7 +57,9 @@ require_once 'Horde/Text/Filter.php';
 require_once 'Horde/History.php';
 
 // Start compression, if requested.
-Horde::compressOutput();
+if (!Util::nonInputVar('no_compress')) {
+    Horde::compressOutput();
+}
 
 // Create a share instance.
 require_once 'Horde/Share.php';
